import { EventEmitter, OnChanges, SimpleChanges } from '@angular/core';
import { TranslateService } from '@ngx-translate/core';
import { BimplusLocalizedWidgetComponent } from "../bimplus-localized-widget/bimplus-localized-widget.component";
import * as i0 from "@angular/core";
export interface MenuItem {
    id: string;
    action: string;
    class: string;
    textId: string;
    type: string;
    checkState: string;
    url: string;
    _url?: () => string;
    textClass: string;
    queryParams: string;
}
export interface MenuItemEventData {
    index: number;
    action: string;
}
export interface LangItem {
    symbol: string;
    text: string;
    lCode: string | undefined;
}
export declare class BimplusUserMenuComponent extends BimplusLocalizedWidgetComponent implements OnChanges {
    constructor(translateService: TranslateService);
    _languagesList: LangItem[];
    /**--------------------------------------------------------------------------
    * States
    --------------------------------------------------------------------------*/
    _menuOpened: boolean;
    _languagesMenuOpened: boolean;
    /**--------------------------------------------------------------------------
    * properties
    --------------------------------------------------------------------------*/
    accountSettingsVisible: boolean;
    removeConnectedAppsVisible: boolean;
    userGuideVisible: boolean;
    supportVisible: boolean;
    forumVisible: boolean;
    releaseNotesVisible: boolean;
    submenuVisible: boolean;
    clearCacheVisible: boolean;
    dividerLoggedInVisible: boolean;
    logoutVisible: boolean;
    isEmbedded: boolean;
    isTouch: boolean;
    allowRcaItem: boolean;
    /**--------------------------------------------------------------------------
    * properties
    --------------------------------------------------------------------------*/
    buttonTitle: string;
    userName: string;
    userPhotoUrl: string;
    userGuideLinkUrl: string;
    supportLinkUrl: string;
    forumLinkUrl: string;
    /**--------------------------------------------------------------------------
    * Component events
    --------------------------------------------------------------------------*/
    bimplusUserMenuClicked: EventEmitter<MenuItemEventData>;
    bimplusLanguageSelected: EventEmitter<string>;
    ngOnChanges(changes: SimpleChanges): void;
    /**--------------------------------------------------------------------------
    * List of menu items
    * Note : action is used to identify action which should be executed
    --------------------------------------------------------------------------*/
    _menuItemsList: MenuItem[];
    /**--------------------------------------------------------------------------
    * Item clicked
    --------------------------------------------------------------------------*/
    _menuItemClicked(item: MenuItem, index: number): void;
    /**--------------------------------------------------------------------------
    * language submenu item clicked
    --------------------------------------------------------------------------*/
    _switchLanguage(language: string): void;
    /**--------------------------------------------------------------------------
    * toggle menu open
    --------------------------------------------------------------------------*/
    _toggleOpened(): void;
    /**--------------------------------------------------------------------------
    * toggle language submenu open
    --------------------------------------------------------------------------*/
    _toggleLanguagesSubmenuOpened(): void;
    /**--------------------------------------------------------------------------
    * check if item is visible
    --------------------------------------------------------------------------*/
    _isHidden(item: MenuItem): boolean;
    _buildUrl(item: MenuItem | undefined): string | undefined;
    _getMenuItems(): (MenuItem | undefined)[];
    _getLangId(lang: LangItem | undefined): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<BimplusUserMenuComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<BimplusUserMenuComponent, "lib-bimplus-user-menu", never, { "accountSettingsVisible": { "alias": "accountSettingsVisible"; "required": false; }; "removeConnectedAppsVisible": { "alias": "removeConnectedAppsVisible"; "required": false; }; "userGuideVisible": { "alias": "userGuideVisible"; "required": false; }; "supportVisible": { "alias": "supportVisible"; "required": false; }; "forumVisible": { "alias": "forumVisible"; "required": false; }; "releaseNotesVisible": { "alias": "releaseNotesVisible"; "required": false; }; "submenuVisible": { "alias": "submenuVisible"; "required": false; }; "clearCacheVisible": { "alias": "clearCacheVisible"; "required": false; }; "dividerLoggedInVisible": { "alias": "dividerLoggedInVisible"; "required": false; }; "logoutVisible": { "alias": "logoutVisible"; "required": false; }; "isEmbedded": { "alias": "isEmbedded"; "required": false; }; "isTouch": { "alias": "isTouch"; "required": false; }; "allowRcaItem": { "alias": "allowRcaItem"; "required": false; }; "buttonTitle": { "alias": "buttonTitle"; "required": false; }; "userName": { "alias": "userName"; "required": false; }; "userPhotoUrl": { "alias": "userPhotoUrl"; "required": false; }; "userGuideLinkUrl": { "alias": "userGuideLinkUrl"; "required": false; }; "supportLinkUrl": { "alias": "supportLinkUrl"; "required": false; }; "forumLinkUrl": { "alias": "forumLinkUrl"; "required": false; }; }, { "bimplusUserMenuClicked": "bimplusUserMenuClicked"; "bimplusLanguageSelected": "bimplusLanguageSelected"; }, never, never, true, never>;
    static ngAcceptInputType_accountSettingsVisible: unknown;
    static ngAcceptInputType_removeConnectedAppsVisible: unknown;
    static ngAcceptInputType_userGuideVisible: unknown;
    static ngAcceptInputType_supportVisible: unknown;
    static ngAcceptInputType_forumVisible: unknown;
    static ngAcceptInputType_releaseNotesVisible: unknown;
    static ngAcceptInputType_submenuVisible: unknown;
    static ngAcceptInputType_clearCacheVisible: unknown;
    static ngAcceptInputType_dividerLoggedInVisible: unknown;
    static ngAcceptInputType_logoutVisible: unknown;
    static ngAcceptInputType_isEmbedded: unknown;
    static ngAcceptInputType_isTouch: unknown;
    static ngAcceptInputType_allowRcaItem: unknown;
}
