import { ElementRef, EventEmitter, OnInit, OnDestroy } from '@angular/core';
import { LayoutManagerService } from '../services/layout-manager.service';
import { ResizeObserverService } from '../services/resize-observer.service';
import * as i0 from "@angular/core";
interface ResizerItem {
    'className': string;
    'resizeStrategy': string;
}
export interface ResizableElement extends HTMLElement {
    resizeStrategy?: string;
}
export declare class ResizableDirective implements OnDestroy, OnInit {
    private elementRef;
    private layoutManagerService;
    private resizeObserverService;
    resizeContactPointX: number;
    resizeContactPointY: number;
    resizableElements: ResizableElement[];
    resizeEnabled: boolean;
    resizeStarted: boolean;
    resizeStart: (event: MouseEvent | TouchEvent) => void;
    resizeInProgress: (event: MouseEvent | TouchEvent) => void;
    boundResizeStart: (event: MouseEvent | TouchEvent) => void;
    boundResizeInProgress: (event: MouseEvent | TouchEvent) => void;
    boundResizeEnd: (event: MouseEvent | TouchEvent) => void;
    _element: HTMLElement;
    actResizeStrategy: string;
    resizedEnd: EventEmitter<MouseEvent>;
    resizersList: ResizerItem[];
    constructor(elementRef: ElementRef, layoutManagerService: LayoutManagerService, resizeObserverService: ResizeObserverService);
    ngOnInit(): void;
    ngOnDestroy(): void;
    resizeEnd(): void;
    /**--------------------------------------------------------------------------
      * find if rectangle 1 is inside rectangle 2
      --------------------------------------------------------------------------*/
    isInsideRect(rect1: DOMRect, rect2: DOMRect): boolean;
    /**--------------------------------------------------------------------------
  * resize rectangle by x, y
  --------------------------------------------------------------------------*/
    _resizeRectangle(rect: DOMRect, resizeX: number, resizeY: number, resizeStrategy: string): DOMRect | undefined;
    _maxHeightReset(obj: HTMLElement, elementRect: DOMRect): void;
    resizeFromTo(obj: HTMLElement, fromX: number, fromY: number, toX: number, toY: number, resizeStrategy: string): boolean;
    /**--------------------------------------------------------------------------
       * resize start at the layout managaer
       * open document listeners
      --------------------------------------------------------------------------*/
    /**--------------------------------------------------------------------------
   * set the elements used for resizing
  --------------------------------------------------------------------------*/
    setResizers(element: HTMLElement): void;
    /**--------------------------------------------------------------------------
    * open mousedown, touchstart listeners on all elements allowed for resizing
    --------------------------------------------------------------------------*/
    openElementListenersResize(): void;
    /**--------------------------------------------------------------------------
      * open mouseup, touchend and mousemove, touchmove on document
     --------------------------------------------------------------------------*/
    openDocumentListenersResize(): void;
    /**--------------------------------------------------------------------------
    * close mouseup, touchend and mousemove, touchmove on document
    --------------------------------------------------------------------------*/
    closeDocumentListenersResize(): void;
    /**--------------------------------------------------------------------------
      * close mousedown, touchstart listeners on all elements allowed for resizing
      --------------------------------------------------------------------------*/
    closeElementListenersResize(): void;
    /**--------------------------------------------------------------------------
    * close all listeners
    --------------------------------------------------------------------------*/
    closeAllListenersResize(): void;
    /**--------------------------------------------------------------------------
      * setup actual resize strategy
     --------------------------------------------------------------------------*/
    setupResizeStrategy(event: MouseEvent | TouchEvent): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ResizableDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ResizableDirective, "[libResizable]", never, {}, { "resizedEnd": "resizedEnd"; }, never, never, true, never>;
}
export {};
