import { ElementRef } from '@angular/core';
import { ResizeObserverService } from './resize-observer.service';
import { LocalStorageService } from './local-storage.service';
import { BehaviorSubject } from 'rxjs';
import * as i0 from "@angular/core";
export interface LayoutManagerItem {
    element: ElementRef;
    id: string;
    selector?: string;
    isCollapsed: boolean;
    rememberPosition?: boolean;
    left?: number;
    top?: number;
    width?: number;
    height?: number;
}
export interface LayoutManagerConfigItem {
    id: string;
    isCollapsed: boolean;
    left?: number;
    top?: number;
    width?: number;
    height?: number;
}
export declare class LayoutManagerService {
    private resizeObserverService;
    private localStorageService;
    registeredItems$: BehaviorSubject<LayoutManagerItem[]>;
    constructor(resizeObserverService: ResizeObserverService, localStorageService: LocalStorageService);
    private registeredItems;
    get RegisteredItems(): LayoutManagerItem[];
    CONFIG: string;
    /**--------------------------------------------------------------------------
      * register object. object must have unique id or elementId
      --------------------------------------------------------------------------*/
    registerObject(obj: ElementRef, id: string, selector: string | undefined, rememberPosition: boolean, left?: number, top?: number, width?: number, height?: number): void;
    _initObject(obj: LayoutManagerItem): void;
    /**--------------------------------------------------------------------------
    * get object configuration
    * return {left, top, width, heigth}
    --------------------------------------------------------------------------*/
    _getObjectConfig(obj: LayoutManagerItem): LayoutManagerConfigItem | null;
    _adjustObjectByConfig(obj: LayoutManagerItem): void;
    _adjustObjectByWindowSize(obj: LayoutManagerItem): void;
    /**--------------------------------------------------------------------------
    * returns object  registered in the layout manager
    --------------------------------------------------------------------------*/
    getItem(id: string): LayoutManagerItem | null;
    /**--------------------------------------------------------------------------
    * set object configuration
    --------------------------------------------------------------------------*/
    _setObjectConfig(obj: LayoutManagerItem, left: number, top: number, width: number, height: number): void;
    getDomParentElement(id: string): HTMLElement | null;
    _getDomParentElement(item: LayoutManagerItem): HTMLElement | null;
    _getDomInternalElement(item: LayoutManagerItem, selector: string | undefined): HTMLElement | null;
    _getElementRect(item: LayoutManagerItem, selector: string | undefined, parentRectangle: DOMRect | undefined): DOMRect | null;
    checkPosition(id: string, selector: string, parentRectangle: DOMRect | undefined, deltaX: number, deltaY: number, forceCheck?: boolean): {
        deltaX: number;
        deltaY: number;
    } | undefined;
    /**--------------------------------------------------------------------------
    * find if rectangle 1 is inside rectangle 2
    --------------------------------------------------------------------------*/
    _isInsideRect(r1: DOMRect, r2: DOMRect): boolean;
    /**--------------------------------------------------------------------------
    * find if rectangles do not overlap the left and top sides
    --------------------------------------------------------------------------*/
    _isInsideLeftTopRect(r1: DOMRect, r2: DOMRect): boolean;
    /**--------------------------------------------------------------------------
    * get position of r1 aligned with the r2 sides
    --------------------------------------------------------------------------*/
    getAlignedPosition(r1: DOMRect, r2: DOMRect): {
        x: number;
        y: number;
    };
    /**--------------------------------------------------------------------------
    * get position of r1 aligned with the r2 left, top sides
    --------------------------------------------------------------------------*/
    _getAlignedLeftTopPosition(r1: DOMRect, r2: DOMRect): {
        x: number;
        y: number;
    };
    /**--------------------------------------------------------------------------
   * translate rectangle by x, y
   --------------------------------------------------------------------------*/
    _translateRectangle(rect: DOMRect, translateX: number, translateY: number): DOMRect | undefined;
    updateCollapsed(value: boolean, id?: string): void;
    handleDragEnd(id: string): void;
    /**--------------------------------------------------------------------------
    * finalize object changes (position). object must be registered in the layout manager
    * object: object to finalize
    --------------------------------------------------------------------------*/
    finalizeObjectChanges(id: string): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<LayoutManagerService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<LayoutManagerService>;
}
